operator > method
Compares two annual dates to see if the left one is strictly later than the right one.
this: First operand of the comparisonrhs: Second operand of the comparison
Returns: true if the this is strictly later than rhs, false otherwise.
Implementation
bool operator >(AnnualDate rhs) {
return compareTo(rhs) > 0;
}