operator < method
Compares two annual dates to see if the left one is strictly earlier than the right one.
this: First operand of the comparisonrhs: Second operand of the comparison
Returns: true if the this is strictly earlier than this, false otherwise.
ArgumentException: The calendar system ofthisis not the same as the calendar ofthis.
Implementation
bool operator <(AnnualDate rhs) {
return compareTo(rhs) < 0;
}