DateAdjusters class
Factory class for date adjusters: functions from LocalDate to LocalDate,
which can be applied to LocalDate, LocalDateTime, and OffsetDateTime.
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- endOfMonth → LocalDate Function(LocalDate)
-
A date adjuster to move to the last day of the current month.
final
- startOfMonth → LocalDate Function(LocalDate)
-
A date adjuster to move to the first day of the current month.
final
Static Methods
-
dayOfMonth(
int day) → LocalDate Function(LocalDate) - A date adjuster to move to the specified day of the current month.
-
month(
int month) → LocalDate Function(LocalDate) - A date adjuster to move to the same day of the specified month.
-
next(
DayOfWeek dayOfWeek) → LocalDate Function(LocalDate) - A date adjuster to move to the next specified day-of-week, adding a week if the day is already correct.
-
nextOrSame(
DayOfWeek dayOfWeek) → LocalDate Function(LocalDate) - A date adjuster to move to the next specified day-of-week, but return the original date if the day is already correct.
-
previous(
DayOfWeek dayOfWeek) → LocalDate Function(LocalDate) - A date adjuster to move to the previous specified day-of-week, subtracting a week if the day is already correct.
-
previousOrSame(
DayOfWeek dayOfWeek) → LocalDate Function(LocalDate) - A date adjuster to move to the previous specified day-of-week, but return the original date if the day is already correct.