operator == method
Compares two DateInterval values for equality.
Date intervals are equal if they have the same start and end dates.
this: The first value to comparerhs: The second value to compare
Returns: True if the two date intervals have the same properties; false otherwise.
Implementation
@override
bool operator ==(Object rhs) =>
rhs is DateInterval && start == rhs.start && end == rhs.end;