equals method

bool equals(
  1. Interval other
)

Indicates whether the value of this interval is equal to the value of the specified interval.

  • other: The value to compare with this instance.

true if the value of this instant is equal to the value of the

Implementation

bool equals(Interval other) =>
    identical(this, other) || _start == other._start && _end == other._end;