hasEnd property
bool
get
hasEnd
Returns true if this interval has a fixed end point, or false if it
extends to the end of time.
Implementation
bool get hasEnd => _end.isValid;
Returns true if this interval has a fixed end point, or false if it
extends to the end of time.
bool get hasEnd => _end.isValid;