hasStart property
bool
get
hasStart
Returns true if this interval has a fixed start point, or false if it
extends to the start of time.
Implementation
bool get hasStart => _start.isValid;
Returns true if this interval has a fixed start point, or false if it
extends to the start of time.
bool get hasStart => _start.isValid;