toString method

  1. @override
String toString()
override

Returns a string representation of this interval, in extended ISO-8601 format: the format is 'start/end' where each instant uses a format of "uuuu'-'MM'-'dd'T'HH':'mm':'ss;FFFFFFFFF'Z'". If the start or end is infinite, the relevant part uses 'StartOfTime' or "EndOfTime" to represent this.

Returns: A string representation of this interval.

Implementation

@override
String toString() {
  var pattern = InstantPattern.extendedIso;
  return pattern.format(_start) + '/' + pattern.format(_end);
}