IslamicEpoch enum
The epoch to use when constructing an Islamic calendar.
The Islamic, or Hijri, calendar can either be constructed starting on July 15th 622CE (in the Julian calendar) or on the following day. The former is the 'astronomical' or "Thursday" epoch; the latter is the "civil" or "Friday" epoch.
Values
- astronomical → const IslamicEpoch
-
Epoch beginning on July 15th 622CE (Julian), which is July 18th 622 CE in the Gregorian calendar. This is the epoch used by the BCL HijriCalendar.
- civil → const IslamicEpoch
-
Epoch beginning on July 16th 622CE (Julian), which is July 19th 622 CE in the Gregorian calendar.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IslamicEpoch> - A constant List of the values in this enum, in order of their declaration.