operator == method
Compares two LocalDate values for equality. This requires that the dates be the same, within the same calendar.
this: The first value to compareother: The second value to compare
Returns: True if the two dates are the same and in the same calendar; false otherwise
Implementation
@override
bool operator ==(Object other) =>
other is LocalDate &&
_yearMonthDayCalendar == other._yearMonthDayCalendar;