periodSince method
Subtracts the specified time from this date, returning the result as a Period.
Cognitively similar to: this - date.
The specified time must be in the same calendar system as this.
date: The date to subtract from this
Returns: The difference between the specified date and this one
Implementation
Period periodSince(LocalDate date) =>
Period.differenceBetweenDates(date, this);