operator == method
Compares two local times for equality, by checking whether they represent the exact same local time, down to the tick.
this: The first value to compareother: The second value to compare
Returns: True if the two times are the same; false otherwise
Implementation
@override
bool operator ==(Object other) =>
other is LocalTime &&
timeSinceMidnight.inNanoseconds == other.timeSinceMidnight.inNanoseconds;