operator > method
Compares two LocalTime values to see if the left one is strictly later than the right one.
this: First operand of the comparisonother: Second operand of the comparison
Returns: true if the this is strictly later than other, false otherwise.
Implementation
bool operator >(LocalTime other) =>
timeSinceMidnight.inNanoseconds > other.timeSinceMidnight.inNanoseconds;