operator >= method
Compares two LocalTime values to see if the left one is later than or equal to the right one.
this: First operand of the comparisonother: Second operand of the comparison
Returns: true if the this is later than or equal to other, false otherwise.
Implementation
bool operator >=(LocalTime other) =>
timeSinceMidnight.inNanoseconds >= other.timeSinceMidnight.inNanoseconds;