periodSince method
Subtracts the specified time from this time, returning the result as a Period.
Cognitively similar to: this - time.
The specified time must be in the same calendar system as this.
time: The time to subtract from this
Returns: The difference between the specified time and this one
Implementation
Period periodSince(LocalTime time) =>
Period.differenceBetweenTimes(time, this);