periodUntil method
Subtracts the specified time from this time, returning the result as a Period.
Cognitively similar to: time - this.
The specified time must be in the same calendar system as this.
time: The time to subtract this from
Returns: The difference between the specified time and this one
Implementation
Period periodUntil(LocalTime time) =>
Period.differenceBetweenTimes(this, time);