weeks property
Gets the number of weeks within this period.
This property returns zero both when the property has been explicitly set to zero and when the period does not contain this property.
Implementation
final int weeks;
Gets the number of weeks within this period.
This property returns zero both when the property has been explicitly set to zero and when the period does not contain this property.
final int weeks;