TimeMachine constructor
TimeMachine()
Implementation
TimeMachine() {
throw StateError(
'TimeMachine can not be instantiated, because no platform has been detected.');
}
TimeMachine() {
throw StateError(
'TimeMachine can not be instantiated, because no platform has been detected.');
}