comment property

String comment
final

Gets the comment (in English) for the mapping, if any.

This is usually used to differentiate between locations in the same country. This will return an empty string if no comment was provided in the original data.

Implementation

final String comment;