countries property

Gets the list of countries associated with this location.

The list is immutable, and will always contain at least one entry. The list is in the order specified in 'zone1970.tab', so the first entry is always the country containing the position indicated by the latitude and longitude, and is the most populous country in the list. No entry in this list is ever null.

Implementation

// todo: make immutable list?
final List<TzdbZone1970LocationCountry> countries;