countryCode property
Gets the ISO-3166 2-letter country code for the country containing the location.
Implementation
final String countryCode;
Gets the ISO-3166 2-letter country code for the country containing the location.
final String countryCode;