countryName property
Gets the English name of the country containing the location, which is never empty.
Implementation
final String countryName;
Gets the English name of the country containing the location, which is never empty.
final String countryName;