plus static method
Adds a duration to a zoned date and time.
zonedDateTime: The value to add the duration to.time: The duration to add
Returns: A new value with the time advanced by the given duration, in the same calendar system and time zone.
Implementation
static ZonedDateTime plus(ZonedDateTime zonedDateTime, Time time) =>
zonedDateTime.add(time);