withResolver method

Creates a pattern for the same original pattern text as this pattern, but with the specified resolver.

  • resolver: The new local mapping resolver to use.

Returns: A new pattern with the given resolver.

Implementation

ZonedDateTimePattern withResolver(ZoneLocalMappingResolver? resolver) =>
    this.resolver == resolver
        ? this
        : _create(
            patternText, _formatInfo, resolver, zoneProvider, templateValue);