TzdbZone1970Location class
A location entry generated from the 'zone1970.tab' file in a TZDB release. This can be used to provide users with a choice of time zone, although it is not internationalized. This is equivalent to TzdbZoneLocation, except that multiple countries may be represented.
- Annotations
-
- @immutable
Constructors
-
TzdbZone1970Location(int latitudeSeconds, int longitudeSeconds, List<
TzdbZone1970LocationCountry?> ? countries, String zoneId, String comment) -
Creates a new location.
factory
Properties
- comment → String
-
Gets the comment (in English) for the mapping, if any.
final
-
countries
→ List<
TzdbZone1970LocationCountry> -
Gets the list of countries associated with this location.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → double
-
Gets the latitude in degrees; positive for North, negative for South.
no setter
- longitude → double
-
Gets the longitude in degrees; positive for East, negative for West.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zoneId → String
-
The ID of the time zone for this location.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited