TzdbZone1970LocationCountry class
A country represented within an entry in the 'zone1970.tab' file, with the English name mapped from the 'iso3166.tab' file.
- Annotations
-
- @immutable
Constructors
- TzdbZone1970LocationCountry(String name, String code)
- Constructs a new country from its name and ISO-3166 2-letter code.
Properties
Methods
-
equals(
TzdbZone1970LocationCountry other) → bool - Compares countries for equality, by name and code.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns a string representation of this country, including the code and name.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override