TzdbZoneLocation class
A location entry generated from the 'zone.tab' file in a TZDB release. This can be used to provide users with a choice of time zone, although it is not internationalized.
- Annotations
-
- @immutable
Constructors
Properties
- comment → String
-
Gets the comment (in English) for the mapping, if any.
final
- countryCode → String
-
Gets the ISO-3166 2-letter country code for the country containing the location.
final
- countryName → String
-
Gets the English name of the country containing the location, which is never empty.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → double
-
Gets the latitude in degrees; positive for North, negative for South.
no setter
- longitude → double
-
Gets the longitude in degrees; positive for East, negative for West.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zoneId → String
-
The ID of the time zone for this location.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited